# gtrace - A Gaussian beam ray-tracing package in python.


## Installation

Just run the setup.py script as follows:


    python setup.py install


That's it !

You can also install it from PyPI by,

    pip install gtrace


## Usage

Please refer to the documents at https://gtrace.readthedocs.io/ .

You can also find more information in the Manuals directory.
